Module model
arcode
0.2.4
Module model
Module Items
Structs
Enums
In crate arcode
arcode
Module
model
Structs

Builder
options in precedence order:
Model
Symbol table for the encoder/decoder. Used to store the probabilities as a vector of counts (number of occurrences). Uniform would be every symbol has a count of 0.
Enums

EOFKind